summaryrefslogtreecommitdiffstats
path: root/c++/src/H5CommonFG.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'c++/src/H5CommonFG.cpp')
-rw-r--r--c++/src/H5CommonFG.cpp10
1 files changed, 4 insertions, 6 deletions
diff --git a/c++/src/H5CommonFG.cpp b/c++/src/H5CommonFG.cpp
index 653cbd1..7cd3705 100644
--- a/c++/src/H5CommonFG.cpp
+++ b/c++/src/H5CommonFG.cpp
@@ -200,15 +200,13 @@ DataSet CommonFG::createDataSet( const H5std_string& name, const DataType& data_
//--------------------------------------------------------------------------
DataSet CommonFG::openDataSet( const char* name ) const
{
// Call C function H5Dopen to open the specified dataset, giving
// the location id and the dataset's name
- hid_t dataset_id = H5Dopen( getLocId(), name );
+ hid_t dataset_id = H5Dopen2( getLocId(), name, H5P_DEFAULT );
// If the dataset's opening failed, throw an exception
- if( dataset_id < 0 )
- {
- throwException("openDataSet", "H5Dopen failed");
- }
+ if(dataset_id < 0)
+ throwException("openDataSet", "H5Dopen2 failed");
// No failure, create and return the DataSet object
DataSet dataset( dataset_id );
@@ -200,15 +200,13 @@ DataSet CommonFG::createDataSet( const H5std_string& name, const DataType& data_
DataSet CommonFG::openDataSet( const char* name ) const
{
- // Call C function H5Dopen to open the specified dataset, giving
+ // Call C function H5Dopen2 to open the specified dataset, giving
// the location id and the dataset's name